==> haskell-primitive-extras-0.10.2.2-95-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-extras
version:              0.10.2.2
visibility:           public
id:                   primitive-extras-0.10.2.2-HvNbg0WFeY75u7f6Y1rBZv
key:                  primitive-extras-0.10.2.2-HvNbg0WFeY75u7f6Y1rBZv
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  ad2857be3afa3e336da6bbb4dde2daba
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.2.2-HvNbg0WFeY75u7f6Y1rBZv
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    deferred-folds-0.9.18.7-FoBSiftVWcT4t8fgfUqevd
    focus-1.0.3.2-9UG6aWIJYQU1dpGJUMaXsH
    foldl-1.4.18-5c5FYHd5uyHBYUMYoaJHy6
    list-t-1.0.5.7-Kce3kPVfPFH8fgauyBPiZn
    primitive-0.9.1.0-CwYB76NvKpqXNq7rVKe89
    primitive-unlifted-2.2.0.0-8TUXTF4LGX11GfvVszqA3g
    profunctors-5.6.3-7SwpvPUR3WDDKDPlUxhog4
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-extras-0.10.2.2-118-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-extras
version:              0.10.2.2
visibility:           public
id:                   primitive-extras-0.10.2.2-IzT8LqspGIn1ThfeqtLyNe
key:                  primitive-extras-0.10.2.2-IzT8LqspGIn1ThfeqtLyNe
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  83218ef369c1d2999a85ed55a602d7b1
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.2.2-IzT8LqspGIn1ThfeqtLyNe
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    deferred-folds-0.9.18.7-3yfE7C237Z7EaNudx50gxt
    focus-1.0.3.2-8hrsVfu9SCyGKwxAyYgRHl
    foldl-1.4.18-OTrisf5BCQDMMVbl8USct
    list-t-1.0.5.7-GdSuNSaT7D1HbJEvfXY0bP
    primitive-0.9.1.0-1TuYyil4nabJdMHni5vWH
    primitive-unlifted-2.2.0.0-ywaus3VxjaDpcUsE5Hx85
    profunctors-5.6.3-GJws21l5du15P9B6ShOpfs
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
